import java.util.ArrayList;
import java.util.List;

/**
 * Representing the Scrabble game. Most of the game logic here
 *
 * @author hajo
 */

public class Scrabble {

    private final WordBook book;
    private final Board board;
    private final List<Player> players;
    private final TileBag bag;
    private Player actual;

    public Scrabble(List<Player> players, TileBag bag, Board board, WordBook book) {
        this.players = players;
        this.board = board;
        this.bag = bag;
        this.book = book;
         for (Player p : players) {
            p.pickTilesFromBag();
        }
        actual = players.get(0);
    }

    public boolean gameOver() {
        return bag.isEmpty();
    }

    public void playerPutTile(int row, int col, int index) {
        Tile t = actual.pickTileFromHolder(index);
        board.add(row, col, t);
    }


    public void playerRemoveTile(int row, int col) {
        Tile t = board.remove(row, col);
        actual.putBackTile(t);
    }

    public void nextPlayer() {
        if (board.tilesCorrectlyPlaced()) {
            // Calculate points and add to player
            board.freezeTiles();
            actual.pickTilesFromBag();
            actual = players.get((players.indexOf(actual) + 1) % players.size());
        } else {
            List<Tile> temps = board.removeTemps();
            for (Tile t : temps) {
                actual.putBackTile(t);
            }
        }
    }

    public Player getActualPlayer() {
        return actual;
    }


    public Board getBoard() {
        return board;
    }

    @Override
    public String toString() {
        return board.toString();
    }


}
